@@ -5,8 +5,8 @@
 
 ;; Author: Artem Khramov <akhramov+emacs@pm.me>
 ;; Created: 6 Jan 2017
-;; Package-Version: 0.7.0
-;; Package-Revision: 832dd0d606f7
+;; Package-Version: 20260123.231
+;; Package-Revision: ea0dddba6046
 ;; Package-Requires: ((alert "1.2") (async "1.9.3") (dash "2.18.0") (emacs "27.1"))
 ;; Keywords: calendar, convenience
 ;; URL: https://github.com/emacsorphanage/org-wild-notifier.el
@@ -226,30 +226,24 @@ in order to ignore seconds."
    (time-add (current-time) (seconds-to-time (* 60 interval)))
    timestamp))
 
-(defun org-wild-notifier--notification-due-now-p (notification)
-  "Return non-nil if NOTIFICATION should fire at the current minute."
-  (org-wild-notifier--time= (plist-get notification :notify-at) (current-time)))
-
-(defun org-wild-notifier--get-current-notifications (event)
-  "Get notifications for EVENT that are due at the current minute.
-Returns a list of notification plists filtered to those due now."
-  (->> (org-wild-notifier--get-notifications-for-event event)
-       (--filter (org-wild-notifier--notification-due-now-p it))))
-
 (defun org-wild-notifier--notifications (event)
-  "Get notifications for given EVENT that are due now.
-Returns a list of notification plists.
-DEPRECATED: Use `org-wild-notifier--get-current-notifications' instead."
-  (org-wild-notifier--get-current-notifications event))
+  "Get notifications for given EVENT.
+Returns a list of time information interval pairs."
+  (->> (list
+        (org-wild-notifier--filter-day-wide-events (cadr (assoc 'times event)))
+        (cdr (assoc 'intervals event)))
+         (apply '-table-flat (lambda (ts int) (list ts int)))
+         ;; When no values are provided for table flat, we get the second values
+         ;; paired with nil.
+         (--filter (not (null (car it))))
+         (--filter (org-wild-notifier--timestamp-within-interval-p (cdar it) (cadr it)))))
 
 (defun org-wild-notifier--has-timestamp (s)
   (string-match org-ts-regexp0 s)
   (match-beginning 7))
 
 (defun org-wild-notifier--filter-day-wide-events (times)
-  "Filter out day-wide events (those without a time component) from TIMES.
-TIMES is a list of time plists with :timestamp-string."
-  (--filter (org-wild-notifier--has-timestamp (plist-get it :timestamp-string)) times))
+  (--filter (org-wild-notifier--has-timestamp (car it)) times))
 
 (defun org-wild-notifier--time-left (seconds)
   "Human-friendly representation for SECONDS."
@@ -315,45 +309,35 @@ TIMES is a list of time plists with :timestamp-string."
            (org-wild-notifier-event-has-any-day-wide-timestamp event))))
 
 (defun org-wild-notifier-event-has-any-day-wide-timestamp (event)
-  "Return non-nil if EVENT has any day-wide timestamp (no time component)."
-  (--any (not (org-wild-notifier--has-timestamp (plist-get it :timestamp-string)))
-         (cadr (assoc 'times event))))
+  (--any (not (org-wild-notifier--has-timestamp (car it)))
+         (car (cdr (assoc 'times event)))))
 
 (defun org-wild-notifier-event-has-any-passed-time (event)
-  "Return non-nil if EVENT has any timestamp that has already passed."
-  (--any (time-less-p (plist-get it :time) (current-time))
-         (cadr (assoc 'times event))))
+  (--any (time-less-p (cdr it) (current-time))
+         (car (cdr (assoc 'times event )))))
 
 (defun org-wild-notifier--day-wide-notification-text (event)
   "For given STR-INTERVAL list and EVENT get notification wording."
   (format "%s is due or scheduled today"
           (cdr (assoc 'title event))))
 
-(defun org-wild-notifier--format-notification (notification)
-  "Format NOTIFICATION plist as a human-readable message string."
-  (let ((type (plist-get notification :type))
-        (title (plist-get notification :title))
-        (event-time-string (plist-get notification :event-time-string))
-        (minutes-before (plist-get notification :minutes-before)))
-    (if (eq type 'absolute)
-        (format "%s (scheduled reminder)" title)
-      (format "%s at %s (%s)"
-              title
-              (org-wild-notifier--get-hh-mm-from-org-time-string event-time-string)
-              (org-wild-notifier--time-left (* 60 minutes-before))))))
-
 (defun org-wild-notifier--check-notify-at (event)
   "Check if any absolute notification times in EVENT match now.
-Returns list of notification plists.
-DEPRECATED: Use `org-wild-notifier--get-current-notifications' instead."
-  (--filter (eq (plist-get it :type) 'absolute)
-            (org-wild-notifier--get-current-notifications event)))
+Returns list of notification messages."
+  (--keep
+   (when (org-wild-notifier--time= it (current-time))
+     (format "%s (scheduled reminder)" (cdr (assoc 'title event))))
+   (cdr (assoc 'notify-at event))))
 
 (defun org-wild-notifier--check-event (event)
-  "Get notifications for given EVENT that are due now.
-Returns a list of notification messages."
-  (->> (org-wild-notifier--get-current-notifications event)
-       (--map (org-wild-notifier--format-notification it))))
+  "Get notifications for given EVENT.
+Returns a list of notification messages"
+  (append
+   ;; Relative time notifications
+   (->> (org-wild-notifier--notifications event)
+        (--map (org-wild-notifier--notification-text `(,(caar it) . ,(cadr it)) event)))
+   ;; Absolute time notifications
+   (org-wild-notifier--check-notify-at event)))
 
 (defun org-wild-notifier--get-tags (marker)
   "Retrieve tags of MARKER."
@@ -502,17 +486,14 @@ First checks for a per-entry override via `org-wild-notifier-entries-property'
 
 (defun org-wild-notifier--extract-time (marker)
   "Extract timestamps from MARKER.
-Returns a list of plists, each containing:
-  :timestamp-type - symbol: deadline, scheduled, or timestamp
-  :timestamp-string - the original org timestamp string
-  :time - parsed time in Emacs time format"
+Timestamps are extracted as cons cells.  car holds org-formatted
+string, cdr holds time in list-of-integer format."
   (-non-nil
    (--map
     (let ((org-timestamp (org-entry-get marker it)))
       (and org-timestamp
-           (list :timestamp-type (intern (downcase it))
-                 :timestamp-string org-timestamp
-                 :time (org-wild-notifier--timestamp-parse org-timestamp))))
+           (cons org-timestamp
+                 (org-wild-notifier--timestamp-parse org-timestamp))))
     (org-wild-notifier--get-entries-for-marker marker))))
 
 (defun org-wild-notifier--extract-title (marker)
@@ -587,8 +568,7 @@ in the WILD_NOTIFIER_NOTIFY_AT property."
 (defun org-wild-notifier--gather-info (marker)
   "Collect information about an event.
 MARKER acts like event's identifier."
-  `((marker . ,marker)
-    (times . (,(org-wild-notifier--extract-time marker)))
+  `((times . (,(org-wild-notifier--extract-time marker)))
     (title . ,(org-wild-notifier--extract-title marker))
     (intervals . ,(org-wild-notifier--extract-notication-intervals marker))
     (notify-at . ,(org-wild-notifier--extract-notify-at-times marker))))
@@ -689,95 +669,6 @@ TIME is a string in HH:MM format or any format accepted by `org-read-date'."
     (message "Notification scheduled for \"%s\" at %s"
              title (format-time-string "%Y-%m-%d %H:%M" target-time))))
 
-(defun org-wild-notifier--get-notifications-for-event (event)
-  "Get all notifications for EVENT.
-Returns a list of notification plists, each containing:
-  :notify-at - Emacs time when notification should fire
-  :event-time - Emacs time of the event (nil for absolute notifications)
-  :event-time-string - Original timestamp string
-  :timestamp-type - Symbol: deadline, scheduled, or timestamp (nil for absolute)
-  :minutes-before - Minutes before event (nil for absolute notifications)
-  :type - Symbol: relative or absolute
-  :title - Event title string
-  :marker - Org marker for navigation/queries
-  :event - The full event alist"
-  (let ((notifications nil)
-        (marker (cdr (assoc 'marker event)))
-        (title (cdr (assoc 'title event)))
-        (times (cadr (assoc 'times event)))
-        (intervals (cdr (assoc 'intervals event)))
-        (notify-at-times (cdr (assoc 'notify-at event))))
-    ;; Check relative notifications (intervals before event times)
-    (dolist (time-info times)
-      (let ((timestamp-string (plist-get time-info :timestamp-string))
-            (event-time (plist-get time-info :time))
-            (timestamp-type (plist-get time-info :timestamp-type)))
-        (when (org-wild-notifier--has-timestamp timestamp-string)
-          (dolist (interval intervals)
-            (let ((notify-time (time-subtract event-time (seconds-to-time (* 60 interval)))))
-              (push (list :notify-at notify-time
-                          :event-time event-time
-                          :event-time-string timestamp-string
-                          :timestamp-type timestamp-type
-                          :minutes-before interval
-                          :type 'relative
-                          :title title
-                          :marker marker
-                          :event event)
-                    notifications))))))
-    ;; Check absolute notifications (notify-at times)
-    (dolist (notify-time notify-at-times)
-      (push (list :notify-at notify-time
-                  :event-time nil
-                  :event-time-string nil
-                  :timestamp-type nil
-                  :minutes-before nil
-                  :type 'absolute
-                  :title title
-                  :marker marker
-                  :event event)
-            notifications))
-    (nreverse notifications)))
-
-(defun org-wild-notifier--gather-events-sync ()
-  "Synchronously gather events from agenda files.
-Returns a list of event alists suitable for notification processing."
-  (let ((org-agenda-use-time-grid nil)
-        (org-agenda-compact-blocks t)
-        (events nil))
-    (save-window-excursion
-      (org-agenda-list 2 (org-read-date nil nil "today"))
-      (with-current-buffer org-agenda-buffer-name
-        (setq events
-              (->> (org-split-string (buffer-string) "\n")
-                   (--map (plist-get
-                           (org-fix-agenda-info (text-properties-at 0 it))
-                           'org-marker))
-                   (-non-nil)
-                   (org-wild-notifier--apply-whitelist)
-                   (org-wild-notifier--apply-blacklist)
-                   (-map 'org-wild-notifier--gather-info))))
-      (kill-buffer org-agenda-buffer-name))
-    events))
-
-;;;###autoload
-(defun org-wild-notifier-get-upcoming-notifications ()
-  "Get all notifications for upcoming events.
-Returns a list of notification plists, each containing:
-  :notify-at - Emacs time when notification should fire
-  :event-time - Emacs time of the event (nil for absolute notifications)
-  :event-time-string - Original timestamp string
-  :minutes-before - Minutes before event (nil for absolute notifications)
-  :type - Symbol 'relative or 'absolute
-  :title - Event title"
-  (let* ((events (org-wild-notifier--gather-events-sync))
-         (all-notifications nil))
-    (dolist (event events)
-      (let ((event-notifications
-             (org-wild-notifier--get-notifications-for-event event)))
-        (setq all-notifications (append all-notifications event-notifications))))
-    all-notifications))
-
 (provide 'org-wild-notifier)
 
 ;;; org-wild-notifier.el ends here
